package com.me.common.ecs;

public final class Entity {

    private static int nextId = 0;

    private Engine engine;

    private int id;
    private boolean active;

    private long componentBits;

    protected Entity(Engine engine) {
        this.engine = engine;
        this.active = false;
        this.id = nextId++;
    }

    public int getId() {
        return id;
    }

    public boolean isActive() {
        return active;
    }

    public void activate() {
        this.active = true;
    }

    public void deactivate() {
        this.active = false;
    }

    public <T extends Component> T getComponent(Class<T> clazz) {
        return engine.getEntityComponent(this, clazz);
    }

    public void addComponent(Component component) {
        engine.addEntityComponent(this, component);
    }

    public void removeComponent(Component component) {
        engine.removeEntityComponent(this, component);
    }

    protected void addComponentType(ComponentType type) {
        componentBits |= type.getBits();
    }

    protected void removeComponentType(ComponentType type) {
        componentBits &= ~type.getBits();
    }

    protected long getComponentBits() {
        return componentBits;
    }

}
